
# Slot: id




URI: [ks:id](https://w3id.org/linkml/tests/kitchen_sink/id)


## Domain and Range

None &#8594;  <sub>1..1</sub> [String](String.md)

## Parents


## Children


## Used by

 * [Company](Company.md)
 * [Concept](Concept.md)
 * [DiagnosisConcept](DiagnosisConcept.md)
 * [Organization](Organization.md)
 * [Person](Person.md)
 * [Place](Place.md)
 * [ProcedureConcept](ProcedureConcept.md)
 * [Activity](Activity.md)
 * [Agent](Agent.md)
